Learn R Programming

actilifecounts (version 1.1.1)

get_counts: get_counts

Description

get_counts

Usage

get_counts(raw, sf, epoch, lfe_select = FALSE, verbose = FALSE)

Value

Matrix containing the count values per epoch in each axis and vector magnitude

Arguments

raw

Matrix containing raw data (3 columns, no timestamp should be included)

sf

Sample frequency of raw data (Hz)

epoch

Epoch length to aggregate activity counts

lfe_select

False for regular trimming, True for allow more noise

verbose

Print diagnostic messages

Author

Jairo Hidalgo Migueles

References

Ali Neishabouri et al. DOI: https://doi.org/10.21203/rs.3.rs-1370418/v1