Description
Generate counts per epoch.
Usage
sum_counts(downsample_10hz, epoch = 60, verbose = FALSE)
Value
Matrix with counts per epoch in the 3 axes
Arguments
- downsample_10hz
Matrix containing downsampled to 10hz data
- epoch
Used to compute how many raw samples are used for computing an epoch
- verbose
Used to compute how many raw samples are used for computing an epoch
Author
Jairo Hidalgo Migueles
References
Ali Neishabouri et al. DOI: https://doi.org/10.21203/rs.3.rs-1370418/v1